# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: payload.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import coord_pb2 as coord__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rpayload.proto\x1a\x0b\x63oord.proto\"\x15\n\x06Strmsg\x12\x0b\n\x03str\x18\x01 \x01(\t\"6\n\nLookatCart\x12\x1a\n\x04\x63\x61rt\x18\x01 \x01(\x0b\x32\x0c.CCartSys3dS\x12\x0c\n\x04head\x18\x02 \x01(\x02\"0\n\x08LookatPx\x12\x16\n\x02px\x18\x01 \x01(\x0b\x32\n.CPoint2dS\x12\x0c\n\x04head\x18\x02 \x01(\x02\"5\n\x0cLookatPerson\x12\x0b\n\x03uid\x18\x03 \x01(\r\x12\x0c\n\x04head\x18\x02 \x01(\x02J\x04\x08\x01\x10\x02R\x04uuid\"8\n\tHeadBndry\x12\r\n\x05v_max\x18\x01 \x01(\x02\x12\r\n\x05\x61_max\x18\x02 \x01(\x02\x12\r\n\x05j_max\x18\x03 \x01(\x02\"(\n\x0bHeadOverlay\x12\x19\n\x07overlay\x18\x01 \x01(\x0b\x32\x08.CBryanS\"e\n\x06HeadFe\x12\x0f\n\x07neutral\x18\x01 \x01(\x02\x12\r\n\x05happy\x18\x02 \x01(\x02\x12\x0b\n\x03sad\x18\x03 \x01(\x02\x12\x10\n\x08surprise\x18\x04 \x01(\x02\x12\r\n\x05\x61nger\x18\x05 \x01(\x02\x12\r\n\x05smile\x18\x06 \x01(\x02\"5\n\x0bHeadEyelids\x12\x12\n\nopenness_l\x18\x01 \x01(\x02\x12\x12\n\nopenness_r\x18\x02 \x01(\x02\"\x1d\n\tHeadMouth\x12\x10\n\x08openness\x18\x01 \x01(\x02\"|\n\tConfigSet\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x03i32\x18\x02 \x01(\x05H\x00\x12\r\n\x03u32\x18\x03 \x01(\rH\x00\x12\r\n\x03i64\x18\x04 \x01(\x03H\x00\x12\r\n\x03u64\x18\x05 \x01(\x04H\x00\x12\r\n\x03\x66\x33\x32\x18\x06 \x01(\x02H\x00\x12\r\n\x03\x66\x36\x34\x18\x07 \x01(\x01H\x00\x42\x07\n\x05value\"*\n\x07\x42\x61seinc\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x12\t\n\x01z\x18\x03 \x01(\x05\" \n\x08\x42\x61setilt\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\"(\n\x04\x41rms\x12\x0f\n\x07\x61ngle_l\x18\x01 \x01(\x05\x12\x0f\n\x07\x61ngle_r\x18\x02 \x01(\x05\"\x1a\n\x0bUidRemember\x12\x0b\n\x03uid\x18\x01 \x01(\r\"\x18\n\tUidForget\x12\x0b\n\x03uid\x18\x01 \x01(\r\"\x1d\n\x0e\x41pproachPerson\x12\x0b\n\x03uid\x18\x01 \x01(\r\"\x16\n\x14\x41pproachPersonCancelb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'payload_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STRMSG._serialized_start=30
  _STRMSG._serialized_end=51
  _LOOKATCART._serialized_start=53
  _LOOKATCART._serialized_end=107
  _LOOKATPX._serialized_start=109
  _LOOKATPX._serialized_end=157
  _LOOKATPERSON._serialized_start=159
  _LOOKATPERSON._serialized_end=212
  _HEADBNDRY._serialized_start=214
  _HEADBNDRY._serialized_end=270
  _HEADOVERLAY._serialized_start=272
  _HEADOVERLAY._serialized_end=312
  _HEADFE._serialized_start=314
  _HEADFE._serialized_end=415
  _HEADEYELIDS._serialized_start=417
  _HEADEYELIDS._serialized_end=470
  _HEADMOUTH._serialized_start=472
  _HEADMOUTH._serialized_end=501
  _CONFIGSET._serialized_start=503
  _CONFIGSET._serialized_end=627
  _BASEINC._serialized_start=629
  _BASEINC._serialized_end=671
  _BASETILT._serialized_start=673
  _BASETILT._serialized_end=705
  _ARMS._serialized_start=707
  _ARMS._serialized_end=747
  _UIDREMEMBER._serialized_start=749
  _UIDREMEMBER._serialized_end=775
  _UIDFORGET._serialized_start=777
  _UIDFORGET._serialized_end=801
  _APPROACHPERSON._serialized_start=803
  _APPROACHPERSON._serialized_end=832
  _APPROACHPERSONCANCEL._serialized_start=834
  _APPROACHPERSONCANCEL._serialized_end=856
# @@protoc_insertion_point(module_scope)
